@@ -35,6 +35,9 @@ class RedisHelper:
     async def keys(self, pattern):
         return await self.get_connection().keys(pattern=pattern)
 
+    async def exists(self, *name):
+        return await self.get_connection().exists(*name)
+
     async def delete(self, names):
         if isinstance(names, list) or isinstance(names, tuple):
             await self.get_connection().delete(*names)
@@ -121,6 +124,9 @@ class RedisHelper:
     def sync_keys(self, pattern):
         return self.get_connection(sync=True).keys(pattern=pattern)
 
+    def sync_exists(self, *name):
+        return self.get_connection(sync=True).exists(*name)
+
     def sync_delete(self, names):
         if isinstance(names, list) or isinstance(names, tuple):
             self.get_connection(sync=True).delete(*names)
