@@ -44,6 +44,8 @@ define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
 define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
 define("scheduler_enable", default=False, type=bool, help="Tornado任务调度")
+define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
+define("scheduler_options", default={}, type=dict, help="Tornado任务调度选项")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -203,6 +205,6 @@ class WebServer:
                 __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
 
     def init_scheduler(self):
-        options.scheduler = TornadoScheduler()
+        options.scheduler = TornadoScheduler(gconfig=options.scheduler_config, **options.scheduler_options)
         options.scheduler.start()
         logging.info('[Scheduler Init]APScheduler has been started')
